<?php

namespace Drupal\eca_state_machine\Plugin\ECA\Event;

use Drupal\eca\Plugin\ECA\Event\EventBase;
use Drupal\state_machine\Event\WorkflowTransitionEvent;

/**
 * Plugin implementation of the ECA Events for state_machine.
 *
 * @EcaEvent(
 *   id = "state_machine",
 *   deriver = "Drupal\eca_state_machine\Plugin\ECA\Event\StateMachineEventDeriver"
 * )
 */
class StateMachineEvent extends EventBase {

  /**
   * @return array[]
   */
  public static function actions(): array {
    $actions = [];

    foreach (['pre_transition', 'post_transition'] as $phase) {
      $actions['state_machine.' . $phase] = [
        'label' => 'State Machine: ' . $phase,
        'event_name' => 'state_machine.' . $phase,
        'event_class' => WorkflowTransitionEvent::class,
      ];
      /**
       * The following events are turned off, because we can't determine
       * the workflows and transitions at this stage. The Drupal container
       * won't be initialized before calling this method.
       * @var \Drupal\state_machine\WorkflowManager $manager
      $manager = \Drupal::service('plugin.manager.workflow');
      foreach ($manager->getDefinitions() as $id => $definition) {
        $workflow = $manager->createInstance($id);
        $group_id = $workflow->getGroup();
        $actions[$group_id . '.' . $phase] = [
          'label' => 'State Machine: ' . $group_id . ' ' . $phase,
          'event_name' => $group_id . '.' . $phase,
          'event_class' => WorkflowTransitionEvent::class,
        ];
        foreach ($workflow->getTransitions() as $transition) {
          $transition_id = $transition->getId();
          $actions[$group_id . '.' . $transition_id . '.' . $phase] = [
            'label' => 'State Machine: ' . $group_id . ' ' . $transition_id . ' ' . $phase,
            'event_name' => $group_id . '.' . $transition_id . '.' . $phase,
            'event_class' => WorkflowTransitionEvent::class,
          ];
        }
      }
       */
    }

    return $actions;
  }

}
